use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::EOL 0.19

use Test::More 0.88;
use Test::EOL;

my @files = (
    'lib/Test/HTML/Tidy/Recursive.pm',
    'lib/Test/HTML/Tidy/Recursive/Strict.pm',
    't/00-compile.t',
    't/data/sample-sites/1/about.html',
    't/data/sample-sites/1/index.html',
    't/inheritance-test-1.t'
);

eol_unix_ok($_, { trailing_whitespace => 1 }) foreach @files;
done_testing;
